@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: asn1-parse
 version: 0.9.4
-id: asn1-parse-0.9.4-7a8ff0bd98d1e72c778de11c366d8b51
-key: asn1p_LrLFPvrxagO8jGmFd1SmqK
+id: asn1-parse-0.9.4-b064d91c5d9874d8c61bb184f001f6aa
+key: asn1p_Az94oiIcQp3FPmwTlFZ3ZX
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-parse-0.9.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-parse-0.9.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-parse-0.9.4
-hs-libraries: HSasn1-parse-0.9.4-LrLFPvrxagO8jGmFd1SmqK
+hs-libraries: HSasn1-parse-0.9.4-Az94oiIcQp3FPmwTlFZ3ZX
 depends:
-    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
-    asn1-types-0.3.2-3969820adc8283f126affe054010f830
+    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
+    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
 haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
